biome
~~~~~

.. image:: https://travis-ci.org/darvid/biome.svg?branch=master
    :target: https://travis-ci.org/darvid/biome

.. image:: https://img.shields.io/pypi/v/biome.svg
    :target: https://pypi.python.org/pypi/biome/

.. image:: https://img.shields.io/pypi/pyversions/biome.svg
    :target: https://pypi.python.org/pypi/biome/

.. image:: https://img.shields.io/pypi/status/biome.svg
    :target: https://pypi.python.org/pypi/biome/

Provides painless access to namespaced environment variables.

Links
-----

* `Source code <http://github.com/darvid/biome>`_
* `Documentation <http://biome.readthedocs.org>`_
